@@ -74,7 +74,7 @@ class VB:
 		command.run()
 		return parser.parse(command.read)
 	
-	def listHdds(self, uuid=None):
+	def listHdds(self, uuid=None, usage=True):
 		"""Return a list of HDDs in use by VirtualBox.  First, we check
 		if a specific HDD was requested.  In this case, we fetch a single
 		HDD by altering the command that is run.  Even if a single HDD is
@@ -92,7 +92,10 @@ class VB:
 		else:
 			command=VBCommand(command=VB_COMMAND_LIST_HDDS)
 			command.run()
-			return parser.parse(command.read)
+			if usage:
+				return parser.parse(command.read)
+			else:
+				return parser.parseSingle(command.read)
 	
 	def getVM(self, uuid):
 		"""Return a specific VirtualBox virtual machine using the specified id.
@@ -221,7 +224,19 @@ class VB:
 		command=VBCommand(command=cmd)
 		command.run()
 		
-	def cloneVDI(self, hdd, path):
-		cmd='%s %s "%s"'%(VB_COMMAND_CLONEVID, hdd.getUUID(), path)
+	def cloneVDI(self, hdd, path, vm=None):
+		cmd='%s %s "%s"'%(VB_COMMAND_CLONEVDI, hdd.getUUID(), path)
 		command=VBCommand(command=cmd)
-		command.run()
\ No newline at end of file
+		command.run()
+		if vm:
+			cloned_hdd=self.registerVDI(path)
+			self.attachVDI(vm, cloned_hdd)
+			return cloned_hdd
+		
+	def registerVDI(self, path):
+		cmd='%s %s "%s"'%(VB_COMMAND_REGISTERIMAGE, 'disk', path)
+		command=VBCommand(command=cmd)
+		command.run()
+		for i in self.listHdds(usage=False):
+			if i.getPath()==path:
+				return i
\ No newline at end of file
