@@ -17,6 +17,7 @@ class vbVmParser(vbParser):
         @return: A new instance.
         @rtype: L{pyvb.vbVmParser}"""
         self.found_attributes={}
+        self.negated_attributes=['primarymaster']
         self.attributes={'name':VB_RE_NAME,\
                          'guestos':VB_RE_GUESTOS,\
                          'uuid':VB_RE_UUID,\
@@ -58,7 +59,7 @@ class vbVmParser(vbParser):
             except KeyError:
                 pass
             try:
-                found_vm.setGuestos(result['guestos'])
+                found_vm.setGuestOS(result['guestos'])
             except KeyError:
                 pass
             try:
@@ -66,19 +67,19 @@ class vbVmParser(vbParser):
             except KeyError:
                 pass
             try:
-                found_vm.setConfigfile(result['configfile'])
+                found_vm.setConfigFile(result['configfile'])
             except KeyError:
                 pass
             try:
-                found_vm.setMemorysize(result['memorysize'])
+                found_vm.setMemorySize(result['memorysize'])
             except KeyError:
                 pass
             try:
-                found_vm.setVramsize(result['vramsize'])
+                found_vm.setVramSize(result['vramsize'])
             except KeyError:
                 pass
             try:
-                found_vm.setBootmenumode(result['bootmenumode'])
+                found_vm.setBootMenuMode(result['bootmenumode'])
             except KeyError:
                 pass
             try:
@@ -90,11 +91,11 @@ class vbVmParser(vbParser):
             except KeyError:
                 pass
             try:
-                found_vm.setTimeoffset(result['timeoffset'])
+                found_vm.setTimeOffset(result['timeoffset'])
             except KeyError:
                 pass
             try:
-                found_vm.setVirtext(result['virtext'])
+                found_vm.setVirtExt(result['virtext'])
             except KeyError:
                 pass
             try:
@@ -102,7 +103,7 @@ class vbVmParser(vbParser):
             except KeyError:
                 pass
             try:
-                found_vm.setMonitorcount(result['monitorcount'])
+                found_vm.setMonitorCount(result['monitorcount'])
             except KeyError:
                 pass
             try:
@@ -110,7 +111,7 @@ class vbVmParser(vbParser):
             except KeyError:
                 pass
             try:
-                found_vm.setPrimarymaster(result['primarymaster'])
+                found_vm.setPrimaryMaster(result['primarymaster'])
             except KeyError:
                 pass
             try:
@@ -142,11 +143,11 @@ class vbVmParser(vbParser):
             except KeyError:
                 pass
             try:
-                found_vm.setClipboardmode(result['clipboardmode'])
+                found_vm.setClipboardMode(result['clipboardmode'])
             except KeyError:
                 pass
             try:
-                found_vm.setSharedfolders(result['sharedfolders'])
+                found_vm.setSharedFolders(result['sharedfolders'])
             except KeyError:
                 pass
             vms.append(found_vm)
@@ -180,29 +181,29 @@ class vbVM:
         except KeyError:
             self.setName('')
         try:
-            self.setGuestos(kw['guestos'])
+            self.setGuestOS(kw['guestos'])
         except KeyError:
-            self.setGuestos('')
+            self.setGuestOS('')
         try:
             self.setUUID(kw['uuid'])
         except KeyError:
             self.setUUID('')
         try:
-            self.setConfigfile(kw['configfile'])
+            self.setConfigFile(kw['configfile'])
         except KeyError:
-            self.setConfigfile('')
+            self.setConfigFile('')
         try:
-            self.setMemorysize(kw['memorysize'])
+            self.setMemorySize(kw['memorysize'])
         except KeyError:
-            self.setMemorysize('')
+            self.setMemorySize('')
         try:
-            self.setVramsize(kw['vramsize'])
+            self.setVramSize(kw['vramsize'])
         except Exception, e:
-            self.setVramsize('')
+            self.setVramSize('')
         try:
-            self.setBootmenumode(kw['bootmenumode'])
+            self.setBootMenuMode(kw['bootmenumode'])
         except KeyError:
-            self.setBootmenumode('')
+            self.setBootMenuMode('')
         try:
             self.setACPI(kw['acpi'])
         except KeyError:
@@ -212,29 +213,29 @@ class vbVM:
         except KeyError:
             self.setIOACPI('')
         try:
-            self.setTimeoffset(kw['timeoffset'])
+            self.setTimeOffset(kw['timeoffset'])
         except KeyError:
-            self.setTimeoffset('')
+            self.setTimeOffset('')
         try:
-            self.setVirtext(kw['virtext'])
+            self.setVirtExt(kw['virtext'])
         except KeyError:
-            self.setVirtext('')
+            self.setVirtExt('')
         try:
             self.setState(kw['state'])
         except KeyError:
             self.setState('')
         try:
-            self.setMonitorcount(kw['monitorcount'])
+            self.setMonitorCount(kw['monitorcount'])
         except KeyError:
-            self.setMonitorcount('')
+            self.setMonitorCount('')
         try:
             self.setFloppy(kw['floppy'])
         except KeyError:
             self.setFloppy('')
         try:
-            self.setPrimarymaster(kw['primarymaster'])
+            self.setPrimaryMaster(kw['primarymaster'])
         except KeyError:
-            self.setPrimarymaster('')
+            self.setPrimaryMaster('')
         try:
             self.setDVD(kw['dvd'])
         except KeyError:
@@ -268,13 +269,13 @@ class vbVM:
         except KeyError:
             self.setAudio('')
         try:
-            self.setClipboardmode(kw['clipboardmode'])
+            self.setClipboardMode(kw['clipboardmode'])
         except KeyError:
-            self.setClipboardmode('')
+            self.setClipboardMode('')
         try:
-            self.setSharedfolders(kw['sharedfolders'])
+            self.setSharedFolders(kw['sharedfolders'])
         except KeyError:
-            self.setSharedfolders('')     
+            self.setSharedFolders('')     
     
     def setName(self, name):
         """Set the name attribute of this L{pyvb.vm.vbVM} instance.
@@ -284,7 +285,7 @@ class vbVM:
         @rtype: None"""
         self.name=name
         
-    def setGuestos(self, guestos):
+    def setGuestOS(self, guestos):
         """Set the guestos attribute of this L{pyvb.vm.vbVM} instance.
         @param guestos: The guestos attribute.
         @type guestos: String
@@ -300,7 +301,7 @@ class vbVM:
         @rtype: None"""
         self.uuid=uuid
         
-    def setConfigfile(self, configfile):
+    def setConfigFile(self, configfile):
         """Set the configfile attribute of this L{pyvb.vm.vbVM} instance.
         @param configfile: The configfile attribute.
         @type configfile: String
@@ -308,7 +309,7 @@ class vbVM:
         @rtype: None"""
         self.configfile=configfile
         
-    def setMemorysize(self, memorysize):
+    def setMemorySize(self, memorysize):
         """Set the memorysize attribute of this L{pyvb.vm.vbVM} instance.
         @param memorysize: The memorysize attribute.
         @type memorysize: String
@@ -316,7 +317,7 @@ class vbVM:
         @rtype: None"""
         self.memorysize=memorysize
         
-    def setVramsize(self, vramsize):
+    def setVramSize(self, vramsize):
         """Set the vramsize attribute of this L{pyvb.vm.vbVM} instance.
         @param vramsize: The vramsize attribute.
         @type vramsize: String
@@ -324,7 +325,7 @@ class vbVM:
         @rtype: None"""
         self.vramsize=vramsize
         
-    def setBootmenumode(self, bootmenumode):
+    def setBootMenuMode(self, bootmenumode):
         """Set the bootmenumode attribute of this L{pyvb.vm.vbVM} instance.
         @param bootmenumode: The bootmenumode attribute.
         @type bootmenumode: String
@@ -348,7 +349,7 @@ class vbVM:
         @rtype: None"""
         self.ioacpi=ioacpi
         
-    def setTimeoffset(self, timeoffset):
+    def setTimeOffset(self, timeoffset):
         """Set the timeoffset attribute of this L{pyvb.vm.vbVM} instance.
         @param timeoffset: The timeoffset attribute.
         @type timeoffset: String
@@ -356,7 +357,7 @@ class vbVM:
         @rtype: None"""
         self.timeoffset=timeoffset
         
-    def setVirtext(self, virtext):
+    def setVirtExt(self, virtext):
         """Set the virtext attribute of this L{pyvb.vm.vbVM} instance.
         @param virtext: The virtext attribute of this L{pyvb.vm.vbVM} instance.
         @type virtext: String
@@ -372,7 +373,7 @@ class vbVM:
         @rtype: None"""
         self.state=state
         
-    def setMonitorcount(self, monitorcount):
+    def setMonitorCount(self, monitorcount):
         """Set the monitorcount attribute of this L{pyvb.vm.vbVM} instance.
         @param monitorcount: The monitorcount attribute.
         @type monitorcount: String
@@ -388,7 +389,7 @@ class vbVM:
         @rtype: None"""
         self.floppy=floppy
         
-    def setPrimarymaster(self, primarymaster):
+    def setPrimaryMaster(self, primarymaster):
         """Set the primarymaster attribute of this L{pyvb.vm.vbVM} instance.
         @param primarymaster: The primarymaster attribute.
         @type primarymaster: String
@@ -460,7 +461,7 @@ class vbVM:
         @rtype: None"""
         self.audio=audio
         
-    def setClipboardmode(self, clipboardmode):
+    def setClipboardMode(self, clipboardmode):
         """Set the clipboardmode attribute of this L{pyvb.vm.vbVM} instance.
         @param clipboardmode: The clipboardmode attribute.
         @type clipboardmode: String
@@ -468,7 +469,7 @@ class vbVM:
         @rtype: None"""
         self.clipboardmode=clipboardmode
         
-    def setSharedfolders(self, sharedfolders):
+    def setSharedFolders(self, sharedfolders):
         """Set the sharedfolders attribute of this L{pyvb.vm.vbVM} instance.
         @param sharedfolders: The sharedfolders attribute.
         @type sharedfolders: String
@@ -482,7 +483,7 @@ class vbVM:
         @rtype: String"""
         return self.name
     
-    def getGuestos(self):
+    def getGuestOS(self):
         """Return the guestos attribute of this L{pyvb.vm.vbVM} instance.
         @return: The guestos attribute.
         @rtype: String"""
@@ -494,25 +495,25 @@ class vbVM:
         @rtype: String"""
         return self.uuid
     
-    def getConfigfile(self):
+    def getConfigFile(self):
         """Return the configfile attribute of this L{pyvb.vm.vbVM} instance.
         @return: The configfile attribute.
         @rtype: String"""
         return self.configfile
     
-    def getMemorysize(self):
+    def getMemorySize(self):
         """Return the memorysize attribute of this L{pyvb.vm.vbVM} instance.
         @return: The memorysize attribute.
         @rtype: String"""
         return self.memorysize
     
-    def getVramsize(self):
+    def getVramSize(self):
         """Return the vramsize attribute of this L{pyvb.vm.vbVM} instance.
         @return: The vramsize attribute.
         @rtype: String"""
         return self.vramsize
     
-    def getBootmenumode(self):
+    def getBootMenuMode(self):
         """Return the bootmenumode attribute of this L{pyvb.vm.vbVM} instance.
         @return: The bootmenumode attribute.
         @rtype: String"""
@@ -530,13 +531,13 @@ class vbVM:
         @rtype: String"""
         return self.ioacpi
     
-    def getTimeoffset(self):
+    def getTimeOffset(self):
         """Return the timeoffset attribute of this L{pyvb.vm.vbVM} instance.
         @return: The timeoffset attribute.
         @rtype: String"""
         return self.timeoffset
     
-    def getVirtext(self):
+    def getVirtExt(self):
         """Return the virtext attribute of this L{pyvb.vm.vbVM} instance.
         @return: The virtext attribute.
         @rtype: String"""
@@ -549,7 +550,7 @@ class vbVM:
         parser=vbStateParser()
         return parser.parse([' %s'%(self.state)])[0]
     
-    def getMonitorcount(self):
+    def getMonitorCount(self):
         """Return the monitorcount attribute of this L{pyvb.vm.vbVM} instance.
         @return: The monitorcount attribute.
         @rtype: String"""
@@ -561,7 +562,7 @@ class vbVM:
         @rtype: String"""
         return self.floppy
     
-    def getPrimarymaster(self):
+    def getPrimaryMaster(self):
         """Return the primarymaster attribute of this L{pyvb.vm.vbVM} instance.
         @return: The primarymaster attribute.
         @rtype: String"""
@@ -615,13 +616,13 @@ class vbVM:
         @rtype: String"""
         return self.audio
     
-    def getClipboardmode(self):
+    def getClipboardMode(self):
         """Return the clipboardmode attribute of this L{pyvb.vm.vbVM} instance.
         @return: The clipboardmode attribute.
         @rtype: String"""
         return self.clipboardmode
     
-    def getSharedfolders(self):
+    def getSharedFolders(self):
         """Return the sharedfolders attribute of this L{pyvb.vm.vbVM} instance.
         @return: The sharedfolders attribute.
         @rtype: String"""
@@ -637,7 +638,7 @@ class vbVM:
         """Return the uuid of this machin's HDD.
         @return: The uuid of the HDD.
         @rtype: String"""
-        uuid=vbVmParser().parseHddUUID(self.getPrimarymaster())
+        uuid=vbVmParser().parseHddUUID(self.getPrimaryMaster())
         parser=vbHddParser()
         cmd='%s %s'%(VB_COMMAND_SHOWVDIINFO, uuid)
         command=VBCommand(command=cmd)
@@ -645,4 +646,7 @@ class vbVM:
         return parser.parseSingle(command.read)[0]
     
     def getStateName(self):
+        """Return the state name of this virtual machine's state.
+        @return: The state name.
+        @rtype: String"""
         return self.getState().getName()
\ No newline at end of file
